'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));
var PropTypes = _interopDefault(require('prop-types'));
var isFunction = _interopDefault(require('lodash/isFunction'));
var tpUiReactInputRow = require('@thumbtack/tp-ui-react-input-row');
var thumbprintIcons = require('@thumbtack/thumbprint-icons');
var classNames = _interopDefault(require('classnames'));
var styles = _interopDefault(require('./index.module.scss'));

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _inherits(subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function");
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      writable: true,
      configurable: true
    }
  });
  if (superClass) _setPrototypeOf(subClass, superClass);
}

function _getPrototypeOf(o) {
  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
    return o.__proto__ || Object.getPrototypeOf(o);
  };
  return _getPrototypeOf(o);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

function _assertThisInitialized(self) {
  if (self === void 0) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return self;
}

function _possibleConstructorReturn(self, call) {
  if (call && (typeof call === "object" || typeof call === "function")) {
    return call;
  }

  return _assertThisInitialized(self);
}

var Context = React.createContext();
/**
 * Prioritize the mutually exclusive UI states the user may end up in.
 */

var getUIState = function getUIState(_ref) {
  var isDisabled = _ref.isDisabled,
      isReadOnly = _ref.isReadOnly,
      hasError = _ref.hasError;

  if (isDisabled) {
    return 'disabled';
  }

  if (isReadOnly) {
    return 'readonly';
  }

  if (hasError) {
    return 'error';
  }

  return 'default';
};
/**
 * This component is not exported. It wraps the `InputClearButton` and `InputIcon`, applying
 * classes to position the icon. It does this by using `create-react-context`, a ponyfill for
 * React’s context functionality. This makes it easier for consumers to use `InputClearButton` and
 * `InputIcon` because they won’t have to specify as many props.
 * @private
 */


var InputIconContainer = function InputIconContainer(props) {
  return React.createElement(Context.Consumer, null, function (theme) {
    var _classNames;

    var position = theme && theme.position;
    var size = theme && theme.size;
    return React.createElement("div", {
      className: classNames((_classNames = {}, _defineProperty(_classNames, styles.inputIconContainer, true), _defineProperty(_classNames, styles.inputIconContainerPositionLeft, position === 'left'), _defineProperty(_classNames, styles.inputIconContainerPositionLeftSizeSmall, position === 'left' && size === 'small'), _defineProperty(_classNames, styles.inputIconContainerPositionLeftSizeLarge, position === 'left' && size === 'large'), _defineProperty(_classNames, styles.inputIconContainerPositionRight, position === 'right'), _defineProperty(_classNames, styles.inputIconContainerPositionRightSizeSmall, position === 'right' && size === 'small'), _defineProperty(_classNames, styles.inputIconContainerPositionRightSizeLarge, position === 'right' && size === 'large'), _classNames))
    }, props.children);
  });
};

InputIconContainer.propTypes = {
  children: PropTypes.node.isRequired
};
/**
 * Accessible button that makes it easy to add a "Clear" button to a text input. It should be used
 * with the `innerRight` prop in `Input`.
 */

var InputClearButton = function InputClearButton(props) {
  return React.createElement(InputIconContainer, null, React.createElement(Context.Consumer, null, function (theme) {
    return React.createElement("div", {
      className: classNames({
        displayNone: theme && !theme.hasValue
      })
    }, React.createElement("button", {
      className: styles.unstyledButton,
      "aria-label": "Clear input",
      onClick: props.onClick,
      type: "button"
    }, React.createElement(thumbprintIcons.NavigationCloseSmall, null)));
  }));
};

InputClearButton.propTypes = {
  /**
   * Function that runs when the clear button is clicked on. This should set `Input`’s `value` to
   * an empty string.
   */
  onClick: PropTypes.func.isRequired
};
var ClearButton = InputClearButton;
/**
 * Component that helps position icons within inputs.
 */

var InputIcon = function InputIcon(_ref2) {
  var color = _ref2.color,
      children = _ref2.children;
  return React.createElement(InputIconContainer, {
    style: {
      color: color
    }
  }, children);
};

InputIcon.propTypes = {
  /**
   * Set the icon color with a color from [Thumbprint Tokens](/api/tokens/).
   * @private
   */
  color: PropTypes.string,

  /**
   * An icon component from [Thumbprint Icons](/api/icons/).
   *
   * You should pair "Medium" icons with `large` inputs and "Small" icons with `small` inputs.
   */
  children: PropTypes.node.isRequired
};
InputIcon.defaultProps = {
  color: 'inherit'
};
/**
 * @default
 */

var Input =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Input, _React$Component);

  function Input(props) {
    var _this;

    _classCallCheck(this, Input);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Input).call(this, props));
    _this.focusInput = _this.focusInput.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    return _this;
  }
  /**
   * Focus the `input` element. This is used to focus on the input when clicking on `innerLeft`
   * or `innerRight`.
   */


  _createClass(Input, [{
    key: "focusInput",
    value: function focusInput() {
      this.input.focus();
    }
  }, {
    key: "render",
    value: function render() {
      var _classNames2,
          _classNames3,
          _this2 = this;

      var _this$props = this.props,
          id = _this$props.id,
          type = _this$props.type,
          isDisabled = _this$props.isDisabled,
          isReadOnly = _this$props.isReadOnly,
          isRequired = _this$props.isRequired,
          hasError = _this$props.hasError,
          placeholder = _this$props.placeholder,
          size = _this$props.size,
          name = _this$props.name,
          value = _this$props.value,
          innerLeft = _this$props.innerLeft,
          innerRight = _this$props.innerRight,
          _onClick = _this$props.onClick,
          _onChange = _this$props.onChange,
          _onFocus = _this$props.onFocus,
          _onBlur = _this$props.onBlur,
          _onKeyDown = _this$props.onKeyDown,
          _onKeyUp = _this$props.onKeyUp,
          shouldFocusOnPageLoad = _this$props.shouldFocusOnPageLoad,
          dataTest = _this$props.dataTest,
          inputMode = _this$props.inputMode,
          pattern = _this$props.pattern,
          maxLength = _this$props.maxLength,
          autoComplete = _this$props.autoComplete;
      var uiState = getUIState({
        isDisabled: isDisabled,
        isReadOnly: isReadOnly,
        hasError: hasError
      });
      /* eslint-disable jsx-a11y/click-events-have-key-events, jsx-a11y/no-static-element-interactions */

      return React.createElement("div", {
        className: classNames((_classNames2 = {}, _defineProperty(_classNames2, styles.root, true), _defineProperty(_classNames2, styles.rootUiStateDefault, uiState === 'default'), _defineProperty(_classNames2, styles.rootUiStateReadonly, uiState === 'readonly'), _defineProperty(_classNames2, styles.rootUiStateDisabled, uiState === 'disabled'), _defineProperty(_classNames2, styles.rootUiStateError, uiState === 'error'), _classNames2))
      }, innerLeft && React.createElement(Context.Provider, {
        value: {
          hasValue: !!value,
          size: size,
          position: 'left'
        }
      }, React.createElement("div", {
        className: styles.inputInnerElement,
        onClick: this.focusInput
      }, innerLeft)), React.createElement("input", {
        className: classNames((_classNames3 = {}, _defineProperty(_classNames3, styles.input, true), _defineProperty(_classNames3, styles.inputSizeSmall, size === 'small'), _defineProperty(_classNames3, styles.inputSizeLarge, size === 'large'), _classNames3)),
        disabled: isDisabled,
        readOnly: isReadOnly,
        required: isRequired,
        placeholder: placeholder // eslint-disable-next-line jsx-a11y/no-autofocus
        ,
        autoFocus: shouldFocusOnPageLoad,
        name: name,
        type: type,
        value: value,
        onChange: function onChange(e) {
          return _onChange(e.target.value, e);
        },
        onClick: function onClick(e) {
          return isFunction(_onClick) && _onClick(e);
        },
        onFocus: function onFocus(e) {
          return isFunction(_onFocus) && _onFocus(e);
        },
        onBlur: function onBlur(e) {
          return isFunction(_onBlur) && _onBlur(e);
        },
        onKeyDown: function onKeyDown(e) {
          return isFunction(_onKeyDown) && _onKeyDown(e);
        },
        onKeyUp: function onKeyUp(e) {
          return isFunction(_onKeyUp) && _onKeyUp(e);
        },
        id: id,
        ref: function ref(el) {
          _this2.input = el;
        },
        "data-test": dataTest,
        inputMode: inputMode,
        pattern: pattern,
        maxLength: maxLength,
        autoComplete: autoComplete
      }), innerRight && React.createElement(Context.Provider, {
        value: {
          hasValue: !!value,
          size: size,
          position: 'right'
        }
      }, React.createElement("div", {
        className: styles.inputInnerElement,
        onClick: this.focusInput
      }, innerRight)), React.createElement(tpUiReactInputRow.InputRowContext.Consumer, null, function (_ref3) {
        var _classNames4;

        var isWithinInputRow = _ref3.isWithinInputRow,
            isFirstInputRowChild = _ref3.isFirstInputRowChild,
            isLastInputRowChild = _ref3.isLastInputRowChild;
        return React.createElement("div", {
          className: classNames((_classNames4 = {}, _defineProperty(_classNames4, styles.inputStyles, true), _defineProperty(_classNames4, styles.inputStylesRoundedBordersLeft, isFirstInputRowChild || !isWithinInputRow), _defineProperty(_classNames4, styles.inputStylesRoundedBordersRight, isLastInputRowChild || !isWithinInputRow), _defineProperty(_classNames4, styles.inputStylesHasNoRightBorder, isWithinInputRow && !isLastInputRowChild), _defineProperty(_classNames4, styles.inputStylesUiStateDefault, uiState === 'default'), _defineProperty(_classNames4, styles.inputStylesUiStateReadonly, uiState === 'readonly'), _defineProperty(_classNames4, styles.inputStylesUiStateDisabled, uiState === 'disabled'), _defineProperty(_classNames4, styles.inputStylesUiStateError, uiState === 'error'), _classNames4))
        });
      }));
    }
  }]);

  return Input;
}(React.Component);

Input.propTypes = {
  /**
   * Adds a HTML `id` attribute to the input. This is used for linking the HTML with a
   * [Label](/ui/tp-ui-react-label/).
   */
  id: PropTypes.string,

  /**
   * Visually and functionally disable the input.
   */
  isDisabled: PropTypes.bool,

  /**
   * Adds `readonly` HTML attribute, allowing users to select (but not modify) the input.
   */
  isReadOnly: PropTypes.bool,

  /**
   * Adds the `required` HTML attribute.
   */
  isRequired: PropTypes.bool,

  /**
   * A regular expression that the `<input>` element's value is checked against when submitting a
   * form.
   */
  pattern: PropTypes.string,

  /**
   * The maximum number of characters that a user can enter. `onChange` will not fire if a user
   * enters a character that exceeds `maxLength`.
   */
  maxLength: PropTypes.string,

  /**
   * Makes the text and border color red.
   */
  hasError: PropTypes.bool,

  /**
   * Text that appears within the input when there is no `value`.
   */
  placeholder: PropTypes.string,

  /**
   * Controls the height and padding of the input.
   */
  size: PropTypes.oneOf(['small', 'large']),

  /**
   * Sets the `type` attribute on the input element.
   */
  type: PropTypes.oneOf(['email', 'password', 'text', 'search', 'tel', 'number']),

  /**
   * A [proposed specification](https://html.spec.whatwg.org/multipage/interaction.html#input-modalities:-the-inputmode-attribute)
   * that enables specification of virtual keyboard type in Chrome. Currently only supported in
   * Chrome and Android.
   */
  inputMode: PropTypes.oneOf(['numeric']),

  /**
   * The HTML `name` attribute that will be pased to the input. It is required if working with a
   * form that uses `<form action="" method="">` to submit data to a server.
   */
  name: PropTypes.string,

  /**
   * The current value of the input.
   */
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired,
  // eslint-disable-line react/require-default-props

  /**
   * Content that appears within the input on the left.
   */
  innerLeft: PropTypes.node,

  /**
   * Content that appears within the input on the right.
   */
  innerRight: PropTypes.node,

  /**
   * The function that is called when the input value changes.
   *
   * It receives two arguments: `onChange(newValue, event)`.
   *
   * The consumer of this component should use that data to update the `value` prop passed in to
   * this component.
   */
  onChange: PropTypes.func.isRequired,

  /**
   * Function that fires when you click into the input.
   */
  onClick: PropTypes.func,

  /**
   * Fires when the input gains focus.
   */
  onFocus: PropTypes.func,

  /**
   * Fires when the input loses focus, regardless of whether the value has changed.
   */
  onBlur: PropTypes.func,

  /**
   * Fires when a key is pressed down with the input focused.
   */
  onKeyDown: PropTypes.func,

  /**
   * Fires when a key press is released with the input focused.
   */
  onKeyUp: PropTypes.func,

  /**
   * This tells the browser to give the input focus when the page is loaded. This can [only be
   * used once on a page](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input#attr-autofocus).
   */
  shouldFocusOnPageLoad: PropTypes.bool,

  /**
   * A selector hook into the React component for use in automated testing environments. It is
   * applied internally to the `<input />` element.
   */
  dataTest: PropTypes.string,

  /**
   * This tells the browser whether to attempt autocompletion of the input. Currently a [subset of
   * specification values are supported](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input).
   */
  autoComplete: PropTypes.oneOf(['off', 'name', 'given-name', 'family-name', 'email', 'postal-code'])
};
Input.defaultProps = {
  id: undefined,
  type: 'text',
  isDisabled: false,
  isReadOnly: false,
  isRequired: false,
  hasError: false,
  placeholder: undefined,
  size: 'large',
  name: undefined,
  value: '',
  innerLeft: undefined,
  innerRight: undefined,
  onClick: undefined,
  onFocus: undefined,
  onBlur: undefined,
  onKeyDown: undefined,
  onKeyUp: undefined,
  shouldFocusOnPageLoad: false,
  dataTest: undefined,
  inputMode: undefined,
  pattern: undefined,
  maxLength: undefined,
  autoComplete: undefined
};

exports.default = Input;
exports.InputIcon = InputIcon;
exports.InputClearButton = InputClearButton;
exports.ClearButton = ClearButton;
//# sourceMappingURL=index.cjs.js.map
